You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airavata.apache.org by ch...@apache.org on 2016/02/24 21:08:12 UTC

[06/16] airavata git commit: removing xsede from usage reporting

removing xsede from usage reporting


Project: http://git-wip-us.apache.org/repos/asf/airavata/repo
Commit: http://git-wip-us.apache.org/repos/asf/airavata/commit/03cd77a4
Tree: http://git-wip-us.apache.org/repos/asf/airavata/tree/03cd77a4
Diff: http://git-wip-us.apache.org/repos/asf/airavata/diff/03cd77a4

Branch: refs/heads/master
Commit: 03cd77a484d72497626bfc759b2328109d0f16e3
Parents: dad110b
Author: smarru <sm...@apache.org>
Authored: Tue Feb 23 15:28:45 2016 -0500
Committer: smarru <sm...@apache.org>
Committed: Tue Feb 23 15:28:45 2016 -0500

----------------------------------------------------------------------
 .../airavata/compute_resource_model_types.cpp   |  24 ++--
 .../lib/airavata/compute_resource_model_types.h |  14 +--
 .../gateway_resource_profile_model_types.cpp    |  24 ++--
 .../gateway_resource_profile_model_types.h      |  14 +--
 .../Model/AppCatalog/ComputeResource/Types.php  |  16 +--
 .../Model/AppCatalog/GatewayProfile/Types.php   |  16 +--
 .../model/appcatalog/computeresource/ttypes.py  |  18 +--
 .../model/appcatalog/gatewayprofile/ttypes.py   |  18 +--
 .../ComputeResourceDescription.java             | 112 +++++++++----------
 .../gatewayprofile/GatewayResourceProfile.java  | 112 +++++++++----------
 .../compute_resource_model.thrift               |   2 +-
 .../gateway_resource_profile_model.thrift       |   2 +-
 12 files changed, 186 insertions(+), 186 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.cpp
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.cpp b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.cpp
index 13bdf38..506bfa0 100644
--- a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.cpp
+++ b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.cpp
@@ -1633,9 +1633,9 @@ void ComputeResourceDescription::__set_maxMemoryPerNode(const int32_t val) {
 __isset.maxMemoryPerNode = true;
 }
 
-void ComputeResourceDescription::__set_xsedeGatewayUsageReporting(const bool val) {
-  this->xsedeGatewayUsageReporting = val;
-__isset.xsedeGatewayUsageReporting = true;
+void ComputeResourceDescription::__set_gatewayUsageReporting(const bool val) {
+  this->gatewayUsageReporting = val;
+__isset.gatewayUsageReporting = true;
 }
 
 void ComputeResourceDescription::__set_gatewayUsageModuleLoadCommand(const std::string& val) {
@@ -1838,8 +1838,8 @@ uint32_t ComputeResourceDescription::read(::apache::thrift::protocol::TProtocol*
         break;
       case 12:
         if (ftype == ::apache::thrift::protocol::T_BOOL) {
-          xfer += iprot->readBool(this->xsedeGatewayUsageReporting);
-          this->__isset.xsedeGatewayUsageReporting = true;
+          xfer += iprot->readBool(this->gatewayUsageReporting);
+          this->__isset.gatewayUsageReporting = true;
         } else {
           xfer += iprot->skip(ftype);
         }
@@ -1983,9 +1983,9 @@ uint32_t ComputeResourceDescription::write(::apache::thrift::protocol::TProtocol
     xfer += oprot->writeI32(this->maxMemoryPerNode);
     xfer += oprot->writeFieldEnd();
   }
-  if (this->__isset.xsedeGatewayUsageReporting) {
-    xfer += oprot->writeFieldBegin("xsedeGatewayUsageReporting", ::apache::thrift::protocol::T_BOOL, 12);
-    xfer += oprot->writeBool(this->xsedeGatewayUsageReporting);
+  if (this->__isset.gatewayUsageReporting) {
+    xfer += oprot->writeFieldBegin("gatewayUsageReporting", ::apache::thrift::protocol::T_BOOL, 12);
+    xfer += oprot->writeBool(this->gatewayUsageReporting);
     xfer += oprot->writeFieldEnd();
   }
   if (this->__isset.gatewayUsageModuleLoadCommand) {
@@ -2016,7 +2016,7 @@ void swap(ComputeResourceDescription &a, ComputeResourceDescription &b) {
   swap(a.jobSubmissionInterfaces, b.jobSubmissionInterfaces);
   swap(a.dataMovementInterfaces, b.dataMovementInterfaces);
   swap(a.maxMemoryPerNode, b.maxMemoryPerNode);
-  swap(a.xsedeGatewayUsageReporting, b.xsedeGatewayUsageReporting);
+  swap(a.gatewayUsageReporting, b.gatewayUsageReporting);
   swap(a.gatewayUsageModuleLoadCommand, b.gatewayUsageModuleLoadCommand);
   swap(a.gatewayUsageExecutable, b.gatewayUsageExecutable);
   swap(a.__isset, b.__isset);
@@ -2034,7 +2034,7 @@ ComputeResourceDescription::ComputeResourceDescription(const ComputeResourceDesc
   jobSubmissionInterfaces = other85.jobSubmissionInterfaces;
   dataMovementInterfaces = other85.dataMovementInterfaces;
   maxMemoryPerNode = other85.maxMemoryPerNode;
-  xsedeGatewayUsageReporting = other85.xsedeGatewayUsageReporting;
+  gatewayUsageReporting = other85.gatewayUsageReporting;
   gatewayUsageModuleLoadCommand = other85.gatewayUsageModuleLoadCommand;
   gatewayUsageExecutable = other85.gatewayUsageExecutable;
   __isset = other85.__isset;
@@ -2051,7 +2051,7 @@ ComputeResourceDescription& ComputeResourceDescription::operator=(const ComputeR
   jobSubmissionInterfaces = other86.jobSubmissionInterfaces;
   dataMovementInterfaces = other86.dataMovementInterfaces;
   maxMemoryPerNode = other86.maxMemoryPerNode;
-  xsedeGatewayUsageReporting = other86.xsedeGatewayUsageReporting;
+  gatewayUsageReporting = other86.gatewayUsageReporting;
   gatewayUsageModuleLoadCommand = other86.gatewayUsageModuleLoadCommand;
   gatewayUsageExecutable = other86.gatewayUsageExecutable;
   __isset = other86.__isset;
@@ -2071,7 +2071,7 @@ void ComputeResourceDescription::printTo(std::ostream& out) const {
   out << ", " << "jobSubmissionInterfaces="; (__isset.jobSubmissionInterfaces ? (out << to_string(jobSubmissionInterfaces)) : (out << "<null>"));
   out << ", " << "dataMovementInterfaces="; (__isset.dataMovementInterfaces ? (out << to_string(dataMovementInterfaces)) : (out << "<null>"));
   out << ", " << "maxMemoryPerNode="; (__isset.maxMemoryPerNode ? (out << to_string(maxMemoryPerNode)) : (out << "<null>"));
-  out << ", " << "xsedeGatewayUsageReporting="; (__isset.xsedeGatewayUsageReporting ? (out << to_string(xsedeGatewayUsageReporting)) : (out << "<null>"));
+  out << ", " << "gatewayUsageReporting="; (__isset.gatewayUsageReporting ? (out << to_string(gatewayUsageReporting)) : (out << "<null>"));
   out << ", " << "gatewayUsageModuleLoadCommand="; (__isset.gatewayUsageModuleLoadCommand ? (out << to_string(gatewayUsageModuleLoadCommand)) : (out << "<null>"));
   out << ", " << "gatewayUsageExecutable="; (__isset.gatewayUsageExecutable ? (out << to_string(gatewayUsageExecutable)) : (out << "<null>"));
   out << ")";

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.h
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.h b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.h
index 82ffc70..2d64916 100644
--- a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.h
+++ b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/compute_resource_model_types.h
@@ -666,7 +666,7 @@ inline std::ostream& operator<<(std::ostream& out, const JobSubmissionInterface&
 }
 
 typedef struct _ComputeResourceDescription__isset {
-  _ComputeResourceDescription__isset() : hostAliases(false), ipAddresses(false), resourceDescription(false), enabled(false), batchQueues(false), fileSystems(false), jobSubmissionInterfaces(false), dataMovementInterfaces(false), maxMemoryPerNode(false), xsedeGatewayUsageReporting(false), gatewayUsageModuleLoadCommand(false), gatewayUsageExecutable(false) {}
+  _ComputeResourceDescription__isset() : hostAliases(false), ipAddresses(false), resourceDescription(false), enabled(false), batchQueues(false), fileSystems(false), jobSubmissionInterfaces(false), dataMovementInterfaces(false), maxMemoryPerNode(false), gatewayUsageReporting(false), gatewayUsageModuleLoadCommand(false), gatewayUsageExecutable(false) {}
   bool hostAliases :1;
   bool ipAddresses :1;
   bool resourceDescription :1;
@@ -676,7 +676,7 @@ typedef struct _ComputeResourceDescription__isset {
   bool jobSubmissionInterfaces :1;
   bool dataMovementInterfaces :1;
   bool maxMemoryPerNode :1;
-  bool xsedeGatewayUsageReporting :1;
+  bool gatewayUsageReporting :1;
   bool gatewayUsageModuleLoadCommand :1;
   bool gatewayUsageExecutable :1;
 } _ComputeResourceDescription__isset;
@@ -686,7 +686,7 @@ class ComputeResourceDescription {
 
   ComputeResourceDescription(const ComputeResourceDescription&);
   ComputeResourceDescription& operator=(const ComputeResourceDescription&);
-  ComputeResourceDescription() : computeResourceId("DO_NOT_SET_AT_CLIENTS"), hostName(), resourceDescription(), enabled(0), maxMemoryPerNode(0), xsedeGatewayUsageReporting(0), gatewayUsageModuleLoadCommand(), gatewayUsageExecutable() {
+  ComputeResourceDescription() : computeResourceId("DO_NOT_SET_AT_CLIENTS"), hostName(), resourceDescription(), enabled(0), maxMemoryPerNode(0), gatewayUsageReporting(0), gatewayUsageModuleLoadCommand(), gatewayUsageExecutable() {
   }
 
   virtual ~ComputeResourceDescription() throw();
@@ -701,7 +701,7 @@ class ComputeResourceDescription {
   std::vector<JobSubmissionInterface>  jobSubmissionInterfaces;
   std::vector< ::apache::airavata::model::data::movement::DataMovementInterface>  dataMovementInterfaces;
   int32_t maxMemoryPerNode;
-  bool xsedeGatewayUsageReporting;
+  bool gatewayUsageReporting;
   std::string gatewayUsageModuleLoadCommand;
   std::string gatewayUsageExecutable;
 
@@ -729,7 +729,7 @@ class ComputeResourceDescription {
 
   void __set_maxMemoryPerNode(const int32_t val);
 
-  void __set_xsedeGatewayUsageReporting(const bool val);
+  void __set_gatewayUsageReporting(const bool val);
 
   void __set_gatewayUsageModuleLoadCommand(const std::string& val);
 
@@ -777,9 +777,9 @@ class ComputeResourceDescription {
       return false;
     else if (__isset.maxMemoryPerNode && !(maxMemoryPerNode == rhs.maxMemoryPerNode))
       return false;
-    if (__isset.xsedeGatewayUsageReporting != rhs.__isset.xsedeGatewayUsageReporting)
+    if (__isset.gatewayUsageReporting != rhs.__isset.gatewayUsageReporting)
       return false;
-    else if (__isset.xsedeGatewayUsageReporting && !(xsedeGatewayUsageReporting == rhs.xsedeGatewayUsageReporting))
+    else if (__isset.gatewayUsageReporting && !(gatewayUsageReporting == rhs.gatewayUsageReporting))
       return false;
     if (__isset.gatewayUsageModuleLoadCommand != rhs.__isset.gatewayUsageModuleLoadCommand)
       return false;

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.cpp
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.cpp b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.cpp
index 761c232..70d5ff6 100644
--- a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.cpp
+++ b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.cpp
@@ -479,9 +479,9 @@ void GatewayResourceProfile::__set_storagePreferences(const std::vector<StorageP
 __isset.storagePreferences = true;
 }
 
-void GatewayResourceProfile::__set_xsedeUsageReportingGatewayId(const std::string& val) {
-  this->xsedeUsageReportingGatewayId = val;
-__isset.xsedeUsageReportingGatewayId = true;
+void GatewayResourceProfile::__set_usageReportingGatewayId(const std::string& val) {
+  this->usageReportingGatewayId = val;
+__isset.usageReportingGatewayId = true;
 }
 
 uint32_t GatewayResourceProfile::read(::apache::thrift::protocol::TProtocol* iprot) {
@@ -564,8 +564,8 @@ uint32_t GatewayResourceProfile::read(::apache::thrift::protocol::TProtocol* ipr
         break;
       case 5:
         if (ftype == ::apache::thrift::protocol::T_STRING) {
-          xfer += iprot->readString(this->xsedeUsageReportingGatewayId);
-          this->__isset.xsedeUsageReportingGatewayId = true;
+          xfer += iprot->readString(this->usageReportingGatewayId);
+          this->__isset.usageReportingGatewayId = true;
         } else {
           xfer += iprot->skip(ftype);
         }
@@ -624,9 +624,9 @@ uint32_t GatewayResourceProfile::write(::apache::thrift::protocol::TProtocol* op
     }
     xfer += oprot->writeFieldEnd();
   }
-  if (this->__isset.xsedeUsageReportingGatewayId) {
-    xfer += oprot->writeFieldBegin("xsedeUsageReportingGatewayId", ::apache::thrift::protocol::T_STRING, 5);
-    xfer += oprot->writeString(this->xsedeUsageReportingGatewayId);
+  if (this->__isset.usageReportingGatewayId) {
+    xfer += oprot->writeFieldBegin("usageReportingGatewayId", ::apache::thrift::protocol::T_STRING, 5);
+    xfer += oprot->writeString(this->usageReportingGatewayId);
     xfer += oprot->writeFieldEnd();
   }
   xfer += oprot->writeFieldStop();
@@ -640,7 +640,7 @@ void swap(GatewayResourceProfile &a, GatewayResourceProfile &b) {
   swap(a.credentialStoreToken, b.credentialStoreToken);
   swap(a.computeResourcePreferences, b.computeResourcePreferences);
   swap(a.storagePreferences, b.storagePreferences);
-  swap(a.xsedeUsageReportingGatewayId, b.xsedeUsageReportingGatewayId);
+  swap(a.usageReportingGatewayId, b.usageReportingGatewayId);
   swap(a.__isset, b.__isset);
 }
 
@@ -649,7 +649,7 @@ GatewayResourceProfile::GatewayResourceProfile(const GatewayResourceProfile& oth
   credentialStoreToken = other18.credentialStoreToken;
   computeResourcePreferences = other18.computeResourcePreferences;
   storagePreferences = other18.storagePreferences;
-  xsedeUsageReportingGatewayId = other18.xsedeUsageReportingGatewayId;
+  usageReportingGatewayId = other18.usageReportingGatewayId;
   __isset = other18.__isset;
 }
 GatewayResourceProfile& GatewayResourceProfile::operator=(const GatewayResourceProfile& other19) {
@@ -657,7 +657,7 @@ GatewayResourceProfile& GatewayResourceProfile::operator=(const GatewayResourceP
   credentialStoreToken = other19.credentialStoreToken;
   computeResourcePreferences = other19.computeResourcePreferences;
   storagePreferences = other19.storagePreferences;
-  xsedeUsageReportingGatewayId = other19.xsedeUsageReportingGatewayId;
+  usageReportingGatewayId = other19.usageReportingGatewayId;
   __isset = other19.__isset;
   return *this;
 }
@@ -668,7 +668,7 @@ void GatewayResourceProfile::printTo(std::ostream& out) const {
   out << ", " << "credentialStoreToken="; (__isset.credentialStoreToken ? (out << to_string(credentialStoreToken)) : (out << "<null>"));
   out << ", " << "computeResourcePreferences="; (__isset.computeResourcePreferences ? (out << to_string(computeResourcePreferences)) : (out << "<null>"));
   out << ", " << "storagePreferences="; (__isset.storagePreferences ? (out << to_string(storagePreferences)) : (out << "<null>"));
-  out << ", " << "xsedeUsageReportingGatewayId="; (__isset.xsedeUsageReportingGatewayId ? (out << to_string(xsedeUsageReportingGatewayId)) : (out << "<null>"));
+  out << ", " << "usageReportingGatewayId="; (__isset.usageReportingGatewayId ? (out << to_string(usageReportingGatewayId)) : (out << "<null>"));
   out << ")";
 }
 

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.h
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.h b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.h
index c858a90..d24a778 100644
--- a/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.h
+++ b/airavata-api/airavata-client-sdks/airavata-cpp-sdk/src/main/resources/lib/airavata/gateway_resource_profile_model_types.h
@@ -220,11 +220,11 @@ inline std::ostream& operator<<(std::ostream& out, const StoragePreference& obj)
 }
 
 typedef struct _GatewayResourceProfile__isset {
-  _GatewayResourceProfile__isset() : credentialStoreToken(false), computeResourcePreferences(false), storagePreferences(false), xsedeUsageReportingGatewayId(false) {}
+  _GatewayResourceProfile__isset() : credentialStoreToken(false), computeResourcePreferences(false), storagePreferences(false), usageReportingGatewayId(false) {}
   bool credentialStoreToken :1;
   bool computeResourcePreferences :1;
   bool storagePreferences :1;
-  bool xsedeUsageReportingGatewayId :1;
+  bool usageReportingGatewayId :1;
 } _GatewayResourceProfile__isset;
 
 class GatewayResourceProfile {
@@ -232,7 +232,7 @@ class GatewayResourceProfile {
 
   GatewayResourceProfile(const GatewayResourceProfile&);
   GatewayResourceProfile& operator=(const GatewayResourceProfile&);
-  GatewayResourceProfile() : gatewayID(), credentialStoreToken(), xsedeUsageReportingGatewayId() {
+  GatewayResourceProfile() : gatewayID(), credentialStoreToken(), usageReportingGatewayId() {
   }
 
   virtual ~GatewayResourceProfile() throw();
@@ -240,7 +240,7 @@ class GatewayResourceProfile {
   std::string credentialStoreToken;
   std::vector<ComputeResourcePreference>  computeResourcePreferences;
   std::vector<StoragePreference>  storagePreferences;
-  std::string xsedeUsageReportingGatewayId;
+  std::string usageReportingGatewayId;
 
   _GatewayResourceProfile__isset __isset;
 
@@ -252,7 +252,7 @@ class GatewayResourceProfile {
 
   void __set_storagePreferences(const std::vector<StoragePreference> & val);
 
-  void __set_xsedeUsageReportingGatewayId(const std::string& val);
+  void __set_usageReportingGatewayId(const std::string& val);
 
   bool operator == (const GatewayResourceProfile & rhs) const
   {
@@ -270,9 +270,9 @@ class GatewayResourceProfile {
       return false;
     else if (__isset.storagePreferences && !(storagePreferences == rhs.storagePreferences))
       return false;
-    if (__isset.xsedeUsageReportingGatewayId != rhs.__isset.xsedeUsageReportingGatewayId)
+    if (__isset.usageReportingGatewayId != rhs.__isset.usageReportingGatewayId)
       return false;
-    else if (__isset.xsedeUsageReportingGatewayId && !(xsedeUsageReportingGatewayId == rhs.xsedeUsageReportingGatewayId))
+    else if (__isset.usageReportingGatewayId && !(usageReportingGatewayId == rhs.usageReportingGatewayId))
       return false;
     return true;
   }

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/ComputeResource/Types.php
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/ComputeResource/Types.php b/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/ComputeResource/Types.php
index 85d77e7..5b79870 100644
--- a/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/ComputeResource/Types.php
+++ b/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/ComputeResource/Types.php
@@ -1719,7 +1719,7 @@ class ComputeResourceDescription {
   /**
    * @var bool
    */
-  public $xsedeGatewayUsageReporting = null;
+  public $gatewayUsageReporting = null;
   /**
    * @var string
    */
@@ -1808,7 +1808,7 @@ class ComputeResourceDescription {
           'type' => TType::I32,
           ),
         12 => array(
-          'var' => 'xsedeGatewayUsageReporting',
+          'var' => 'gatewayUsageReporting',
           'type' => TType::BOOL,
           ),
         13 => array(
@@ -1855,8 +1855,8 @@ class ComputeResourceDescription {
       if (isset($vals['maxMemoryPerNode'])) {
         $this->maxMemoryPerNode = $vals['maxMemoryPerNode'];
       }
-      if (isset($vals['xsedeGatewayUsageReporting'])) {
-        $this->xsedeGatewayUsageReporting = $vals['xsedeGatewayUsageReporting'];
+      if (isset($vals['gatewayUsageReporting'])) {
+        $this->gatewayUsageReporting = $vals['gatewayUsageReporting'];
       }
       if (isset($vals['gatewayUsageModuleLoadCommand'])) {
         $this->gatewayUsageModuleLoadCommand = $vals['gatewayUsageModuleLoadCommand'];
@@ -2031,7 +2031,7 @@ class ComputeResourceDescription {
           break;
         case 12:
           if ($ftype == TType::BOOL) {
-            $xfer += $input->readBool($this->xsedeGatewayUsageReporting);
+            $xfer += $input->readBool($this->gatewayUsageReporting);
           } else {
             $xfer += $input->skip($ftype);
           }
@@ -2191,9 +2191,9 @@ class ComputeResourceDescription {
       $xfer += $output->writeI32($this->maxMemoryPerNode);
       $xfer += $output->writeFieldEnd();
     }
-    if ($this->xsedeGatewayUsageReporting !== null) {
-      $xfer += $output->writeFieldBegin('xsedeGatewayUsageReporting', TType::BOOL, 12);
-      $xfer += $output->writeBool($this->xsedeGatewayUsageReporting);
+    if ($this->gatewayUsageReporting !== null) {
+      $xfer += $output->writeFieldBegin('gatewayUsageReporting', TType::BOOL, 12);
+      $xfer += $output->writeBool($this->gatewayUsageReporting);
       $xfer += $output->writeFieldEnd();
     }
     if ($this->gatewayUsageModuleLoadCommand !== null) {

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/GatewayProfile/Types.php
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/GatewayProfile/Types.php b/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/GatewayProfile/Types.php
index 3374c24..37e7837 100644
--- a/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/GatewayProfile/Types.php
+++ b/airavata-api/airavata-client-sdks/airavata-php-sdk/src/main/resources/lib/Airavata/Model/AppCatalog/GatewayProfile/Types.php
@@ -489,7 +489,7 @@ class GatewayResourceProfile {
   /**
    * @var string
    */
-  public $xsedeUsageReportingGatewayId = null;
+  public $usageReportingGatewayId = null;
 
   public function __construct($vals=null) {
     if (!isset(self::$_TSPEC)) {
@@ -521,7 +521,7 @@ class GatewayResourceProfile {
             ),
           ),
         5 => array(
-          'var' => 'xsedeUsageReportingGatewayId',
+          'var' => 'usageReportingGatewayId',
           'type' => TType::STRING,
           ),
         );
@@ -539,8 +539,8 @@ class GatewayResourceProfile {
       if (isset($vals['storagePreferences'])) {
         $this->storagePreferences = $vals['storagePreferences'];
       }
-      if (isset($vals['xsedeUsageReportingGatewayId'])) {
-        $this->xsedeUsageReportingGatewayId = $vals['xsedeUsageReportingGatewayId'];
+      if (isset($vals['usageReportingGatewayId'])) {
+        $this->usageReportingGatewayId = $vals['usageReportingGatewayId'];
       }
     }
   }
@@ -616,7 +616,7 @@ class GatewayResourceProfile {
           break;
         case 5:
           if ($ftype == TType::STRING) {
-            $xfer += $input->readString($this->xsedeUsageReportingGatewayId);
+            $xfer += $input->readString($this->usageReportingGatewayId);
           } else {
             $xfer += $input->skip($ftype);
           }
@@ -678,9 +678,9 @@ class GatewayResourceProfile {
       }
       $xfer += $output->writeFieldEnd();
     }
-    if ($this->xsedeUsageReportingGatewayId !== null) {
-      $xfer += $output->writeFieldBegin('xsedeUsageReportingGatewayId', TType::STRING, 5);
-      $xfer += $output->writeString($this->xsedeUsageReportingGatewayId);
+    if ($this->usageReportingGatewayId !== null) {
+      $xfer += $output->writeFieldBegin('usageReportingGatewayId', TType::STRING, 5);
+      $xfer += $output->writeString($this->usageReportingGatewayId);
       $xfer += $output->writeFieldEnd();
     }
     $xfer += $output->writeFieldStop();

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/computeresource/ttypes.py
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/computeresource/ttypes.py b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/computeresource/ttypes.py
index 36e403d..7b319f6 100644
--- a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/computeresource/ttypes.py
+++ b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/computeresource/ttypes.py
@@ -1340,7 +1340,7 @@ class ComputeResourceDescription:
    - jobSubmissionInterfaces
    - dataMovementInterfaces
    - maxMemoryPerNode
-   - xsedeGatewayUsageReporting
+   - gatewayUsageReporting
    - gatewayUsageModuleLoadCommand
    - gatewayUsageExecutable
   """
@@ -1358,12 +1358,12 @@ class ComputeResourceDescription:
     (9, TType.LIST, 'jobSubmissionInterfaces', (TType.STRUCT,(JobSubmissionInterface, JobSubmissionInterface.thrift_spec)), None, ), # 9
     (10, TType.LIST, 'dataMovementInterfaces', (TType.STRUCT,(apache.airavata.model.data.movement.ttypes.DataMovementInterface, apache.airavata.model.data.movement.ttypes.DataMovementInterface.thrift_spec)), None, ), # 10
     (11, TType.I32, 'maxMemoryPerNode', None, None, ), # 11
-    (12, TType.BOOL, 'xsedeGatewayUsageReporting', None, None, ), # 12
+    (12, TType.BOOL, 'gatewayUsageReporting', None, None, ), # 12
     (13, TType.STRING, 'gatewayUsageModuleLoadCommand', None, None, ), # 13
     (14, TType.STRING, 'gatewayUsageExecutable', None, None, ), # 14
   )
 
-  def __init__(self, computeResourceId=thrift_spec[1][4], hostName=None, hostAliases=None, ipAddresses=None, resourceDescription=None, enabled=None, batchQueues=None, fileSystems=None, jobSubmissionInterfaces=None, dataMovementInterfaces=None, maxMemoryPerNode=None, xsedeGatewayUsageReporting=None, gatewayUsageModuleLoadCommand=None, gatewayUsageExecutable=None,):
+  def __init__(self, computeResourceId=thrift_spec[1][4], hostName=None, hostAliases=None, ipAddresses=None, resourceDescription=None, enabled=None, batchQueues=None, fileSystems=None, jobSubmissionInterfaces=None, dataMovementInterfaces=None, maxMemoryPerNode=None, gatewayUsageReporting=None, gatewayUsageModuleLoadCommand=None, gatewayUsageExecutable=None,):
     self.computeResourceId = computeResourceId
     self.hostName = hostName
     self.hostAliases = hostAliases
@@ -1375,7 +1375,7 @@ class ComputeResourceDescription:
     self.jobSubmissionInterfaces = jobSubmissionInterfaces
     self.dataMovementInterfaces = dataMovementInterfaces
     self.maxMemoryPerNode = maxMemoryPerNode
-    self.xsedeGatewayUsageReporting = xsedeGatewayUsageReporting
+    self.gatewayUsageReporting = gatewayUsageReporting
     self.gatewayUsageModuleLoadCommand = gatewayUsageModuleLoadCommand
     self.gatewayUsageExecutable = gatewayUsageExecutable
 
@@ -1479,7 +1479,7 @@ class ComputeResourceDescription:
           iprot.skip(ftype)
       elif fid == 12:
         if ftype == TType.BOOL:
-          self.xsedeGatewayUsageReporting = iprot.readBool()
+          self.gatewayUsageReporting = iprot.readBool()
         else:
           iprot.skip(ftype)
       elif fid == 13:
@@ -1565,9 +1565,9 @@ class ComputeResourceDescription:
       oprot.writeFieldBegin('maxMemoryPerNode', TType.I32, 11)
       oprot.writeI32(self.maxMemoryPerNode)
       oprot.writeFieldEnd()
-    if self.xsedeGatewayUsageReporting is not None:
-      oprot.writeFieldBegin('xsedeGatewayUsageReporting', TType.BOOL, 12)
-      oprot.writeBool(self.xsedeGatewayUsageReporting)
+    if self.gatewayUsageReporting is not None:
+      oprot.writeFieldBegin('gatewayUsageReporting', TType.BOOL, 12)
+      oprot.writeBool(self.gatewayUsageReporting)
       oprot.writeFieldEnd()
     if self.gatewayUsageModuleLoadCommand is not None:
       oprot.writeFieldBegin('gatewayUsageModuleLoadCommand', TType.STRING, 13)
@@ -1601,7 +1601,7 @@ class ComputeResourceDescription:
     value = (value * 31) ^ hash(self.jobSubmissionInterfaces)
     value = (value * 31) ^ hash(self.dataMovementInterfaces)
     value = (value * 31) ^ hash(self.maxMemoryPerNode)
-    value = (value * 31) ^ hash(self.xsedeGatewayUsageReporting)
+    value = (value * 31) ^ hash(self.gatewayUsageReporting)
     value = (value * 31) ^ hash(self.gatewayUsageModuleLoadCommand)
     value = (value * 31) ^ hash(self.gatewayUsageExecutable)
     return value

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/gatewayprofile/ttypes.py
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/gatewayprofile/ttypes.py b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/gatewayprofile/ttypes.py
index a5f9620..ddd0723 100644
--- a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/gatewayprofile/ttypes.py
+++ b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/appcatalog/gatewayprofile/ttypes.py
@@ -351,7 +351,7 @@ class GatewayResourceProfile:
    - credentialStoreToken
    - computeResourcePreferences
    - storagePreferences
-   - xsedeUsageReportingGatewayId
+   - usageReportingGatewayId
   """
 
   thrift_spec = (
@@ -360,15 +360,15 @@ class GatewayResourceProfile:
     (2, TType.STRING, 'credentialStoreToken', None, None, ), # 2
     (3, TType.LIST, 'computeResourcePreferences', (TType.STRUCT,(ComputeResourcePreference, ComputeResourcePreference.thrift_spec)), None, ), # 3
     (4, TType.LIST, 'storagePreferences', (TType.STRUCT,(StoragePreference, StoragePreference.thrift_spec)), None, ), # 4
-    (5, TType.STRING, 'xsedeUsageReportingGatewayId', None, None, ), # 5
+    (5, TType.STRING, 'usageReportingGatewayId', None, None, ), # 5
   )
 
-  def __init__(self, gatewayID=None, credentialStoreToken=None, computeResourcePreferences=None, storagePreferences=None, xsedeUsageReportingGatewayId=None,):
+  def __init__(self, gatewayID=None, credentialStoreToken=None, computeResourcePreferences=None, storagePreferences=None, usageReportingGatewayId=None,):
     self.gatewayID = gatewayID
     self.credentialStoreToken = credentialStoreToken
     self.computeResourcePreferences = computeResourcePreferences
     self.storagePreferences = storagePreferences
-    self.xsedeUsageReportingGatewayId = xsedeUsageReportingGatewayId
+    self.usageReportingGatewayId = usageReportingGatewayId
 
   def read(self, iprot):
     if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
@@ -413,7 +413,7 @@ class GatewayResourceProfile:
           iprot.skip(ftype)
       elif fid == 5:
         if ftype == TType.STRING:
-          self.xsedeUsageReportingGatewayId = iprot.readString()
+          self.usageReportingGatewayId = iprot.readString()
         else:
           iprot.skip(ftype)
       else:
@@ -448,9 +448,9 @@ class GatewayResourceProfile:
         iter13.write(oprot)
       oprot.writeListEnd()
       oprot.writeFieldEnd()
-    if self.xsedeUsageReportingGatewayId is not None:
-      oprot.writeFieldBegin('xsedeUsageReportingGatewayId', TType.STRING, 5)
-      oprot.writeString(self.xsedeUsageReportingGatewayId)
+    if self.usageReportingGatewayId is not None:
+      oprot.writeFieldBegin('usageReportingGatewayId', TType.STRING, 5)
+      oprot.writeString(self.usageReportingGatewayId)
       oprot.writeFieldEnd()
     oprot.writeFieldStop()
     oprot.writeStructEnd()
@@ -467,7 +467,7 @@ class GatewayResourceProfile:
     value = (value * 31) ^ hash(self.credentialStoreToken)
     value = (value * 31) ^ hash(self.computeResourcePreferences)
     value = (value * 31) ^ hash(self.storagePreferences)
-    value = (value * 31) ^ hash(self.xsedeUsageReportingGatewayId)
+    value = (value * 31) ^ hash(self.usageReportingGatewayId)
     return value
 
   def __repr__(self):

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/computeresource/ComputeResourceDescription.java
----------------------------------------------------------------------
diff --git a/thrift-interface-descriptions/data-models/resource-catalog-models/compute_resource_model.thrift b/thrift-interface-descriptions/data-models/resource-catalog-models/compute_resource_model.thrift
index 44ff7ab..66b6528 100644
--- a/thrift-interface-descriptions/data-models/resource-catalog-models/compute_resource_model.thrift
+++ b/thrift-interface-descriptions/data-models/resource-catalog-models/compute_resource_model.thrift
@@ -345,7 +345,7 @@ struct ComputeResourceDescription {
     9: optional list<JobSubmissionInterface> jobSubmissionInterfaces,
     10: optional list<data_movement_models.DataMovementInterface> dataMovementInterfaces,
     11: optional i32 maxMemoryPerNode,
-    12: optional bool xsedeGatewayUsageReporting,
+    12: optional bool gatewayUsageReporting,
     13: optional string gatewayUsageModuleLoadCommand,
     14: optional string gatewayUsageExecutable
 }

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/thrift-interface-descriptions/data-models/resource-catalog-models/gateway_resource_profile_model.thrift
----------------------------------------------------------------------
diff --git a/thrift-interface-descriptions/data-models/resource-catalog-models/gateway_resource_profile_model.thrift b/thrift-interface-descriptions/data-models/resource-catalog-models/gateway_resource_profile_model.thrift
index 6bd3001..9447e97 100644
--- a/thrift-interface-descriptions/data-models/resource-catalog-models/gateway_resource_profile_model.thrift
+++ b/thrift-interface-descriptions/data-models/resource-catalog-models/gateway_resource_profile_model.thrift
@@ -97,5 +97,5 @@ struct GatewayResourceProfile {
     2: optional string credentialStoreToken,
     3: optional list<ComputeResourcePreference> computeResourcePreferences,
     4: optional list<StoragePreference> storagePreferences,
-    5: optional string xsedeUsageReportingGatewayId
+    5: optional string usageReportingGatewayId
 }
diff --git a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/computeresource/ComputeResourceDescription.java b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/computeresource/ComputeResourceDescription.java
index c77ed54..5c4511c 100644
--- a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/computeresource/ComputeResourceDescription.java
+++ b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/computeresource/ComputeResourceDescription.java
@@ -95,7 +95,7 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
   private static final org.apache.thrift.protocol.TField JOB_SUBMISSION_INTERFACES_FIELD_DESC = new org.apache.thrift.protocol.TField("jobSubmissionInterfaces", org.apache.thrift.protocol.TType.LIST, (short)9);
   private static final org.apache.thrift.protocol.TField DATA_MOVEMENT_INTERFACES_FIELD_DESC = new org.apache.thrift.protocol.TField("dataMovementInterfaces", org.apache.thrift.protocol.TType.LIST, (short)10);
   private static final org.apache.thrift.protocol.TField MAX_MEMORY_PER_NODE_FIELD_DESC = new org.apache.thrift.protocol.TField("maxMemoryPerNode", org.apache.thrift.protocol.TType.I32, (short)11);
-  private static final org.apache.thrift.protocol.TField XSEDE_GATEWAY_USAGE_REPORTING_FIELD_DESC = new org.apache.thrift.protocol.TField("xsedeGatewayUsageReporting", org.apache.thrift.protocol.TType.BOOL, (short)12);
+  private static final org.apache.thrift.protocol.TField GATEWAY_USAGE_REPORTING_FIELD_DESC = new org.apache.thrift.protocol.TField("gatewayUsageReporting", org.apache.thrift.protocol.TType.BOOL, (short)12);
   private static final org.apache.thrift.protocol.TField GATEWAY_USAGE_MODULE_LOAD_COMMAND_FIELD_DESC = new org.apache.thrift.protocol.TField("gatewayUsageModuleLoadCommand", org.apache.thrift.protocol.TType.STRING, (short)13);
   private static final org.apache.thrift.protocol.TField GATEWAY_USAGE_EXECUTABLE_FIELD_DESC = new org.apache.thrift.protocol.TField("gatewayUsageExecutable", org.apache.thrift.protocol.TType.STRING, (short)14);
 
@@ -116,7 +116,7 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
   private List<JobSubmissionInterface> jobSubmissionInterfaces; // optional
   private List<org.apache.airavata.model.data.movement.DataMovementInterface> dataMovementInterfaces; // optional
   private int maxMemoryPerNode; // optional
-  private boolean xsedeGatewayUsageReporting; // optional
+  private boolean gatewayUsageReporting; // optional
   private String gatewayUsageModuleLoadCommand; // optional
   private String gatewayUsageExecutable; // optional
 
@@ -133,7 +133,7 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
     JOB_SUBMISSION_INTERFACES((short)9, "jobSubmissionInterfaces"),
     DATA_MOVEMENT_INTERFACES((short)10, "dataMovementInterfaces"),
     MAX_MEMORY_PER_NODE((short)11, "maxMemoryPerNode"),
-    XSEDE_GATEWAY_USAGE_REPORTING((short)12, "xsedeGatewayUsageReporting"),
+    GATEWAY_USAGE_REPORTING((short)12, "gatewayUsageReporting"),
     GATEWAY_USAGE_MODULE_LOAD_COMMAND((short)13, "gatewayUsageModuleLoadCommand"),
     GATEWAY_USAGE_EXECUTABLE((short)14, "gatewayUsageExecutable");
 
@@ -172,8 +172,8 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
           return DATA_MOVEMENT_INTERFACES;
         case 11: // MAX_MEMORY_PER_NODE
           return MAX_MEMORY_PER_NODE;
-        case 12: // XSEDE_GATEWAY_USAGE_REPORTING
-          return XSEDE_GATEWAY_USAGE_REPORTING;
+        case 12: // GATEWAY_USAGE_REPORTING
+          return GATEWAY_USAGE_REPORTING;
         case 13: // GATEWAY_USAGE_MODULE_LOAD_COMMAND
           return GATEWAY_USAGE_MODULE_LOAD_COMMAND;
         case 14: // GATEWAY_USAGE_EXECUTABLE
@@ -220,9 +220,9 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
   // isset id assignments
   private static final int __ENABLED_ISSET_ID = 0;
   private static final int __MAXMEMORYPERNODE_ISSET_ID = 1;
-  private static final int __XSEDEGATEWAYUSAGEREPORTING_ISSET_ID = 2;
+  private static final int __GATEWAYUSAGEREPORTING_ISSET_ID = 2;
   private byte __isset_bitfield = 0;
-  private static final _Fields optionals[] = {_Fields.HOST_ALIASES,_Fields.IP_ADDRESSES,_Fields.RESOURCE_DESCRIPTION,_Fields.ENABLED,_Fields.BATCH_QUEUES,_Fields.FILE_SYSTEMS,_Fields.JOB_SUBMISSION_INTERFACES,_Fields.DATA_MOVEMENT_INTERFACES,_Fields.MAX_MEMORY_PER_NODE,_Fields.XSEDE_GATEWAY_USAGE_REPORTING,_Fields.GATEWAY_USAGE_MODULE_LOAD_COMMAND,_Fields.GATEWAY_USAGE_EXECUTABLE};
+  private static final _Fields optionals[] = {_Fields.HOST_ALIASES,_Fields.IP_ADDRESSES,_Fields.RESOURCE_DESCRIPTION,_Fields.ENABLED,_Fields.BATCH_QUEUES,_Fields.FILE_SYSTEMS,_Fields.JOB_SUBMISSION_INTERFACES,_Fields.DATA_MOVEMENT_INTERFACES,_Fields.MAX_MEMORY_PER_NODE,_Fields.GATEWAY_USAGE_REPORTING,_Fields.GATEWAY_USAGE_MODULE_LOAD_COMMAND,_Fields.GATEWAY_USAGE_EXECUTABLE};
   public static final Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> metaDataMap;
   static {
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
@@ -255,7 +255,7 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
             new org.apache.thrift.meta_data.StructMetaData(org.apache.thrift.protocol.TType.STRUCT, org.apache.airavata.model.data.movement.DataMovementInterface.class))));
     tmpMap.put(_Fields.MAX_MEMORY_PER_NODE, new org.apache.thrift.meta_data.FieldMetaData("maxMemoryPerNode", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I32)));
-    tmpMap.put(_Fields.XSEDE_GATEWAY_USAGE_REPORTING, new org.apache.thrift.meta_data.FieldMetaData("xsedeGatewayUsageReporting", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
+    tmpMap.put(_Fields.GATEWAY_USAGE_REPORTING, new org.apache.thrift.meta_data.FieldMetaData("gatewayUsageReporting", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.BOOL)));
     tmpMap.put(_Fields.GATEWAY_USAGE_MODULE_LOAD_COMMAND, new org.apache.thrift.meta_data.FieldMetaData("gatewayUsageModuleLoadCommand", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
@@ -339,7 +339,7 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
       this.dataMovementInterfaces = __this__dataMovementInterfaces;
     }
     this.maxMemoryPerNode = other.maxMemoryPerNode;
-    this.xsedeGatewayUsageReporting = other.xsedeGatewayUsageReporting;
+    this.gatewayUsageReporting = other.gatewayUsageReporting;
     if (other.isSetGatewayUsageModuleLoadCommand()) {
       this.gatewayUsageModuleLoadCommand = other.gatewayUsageModuleLoadCommand;
     }
@@ -368,8 +368,8 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
     this.dataMovementInterfaces = null;
     setMaxMemoryPerNodeIsSet(false);
     this.maxMemoryPerNode = 0;
-    setXsedeGatewayUsageReportingIsSet(false);
-    this.xsedeGatewayUsageReporting = false;
+    setGatewayUsageReportingIsSet(false);
+    this.gatewayUsageReporting = false;
     this.gatewayUsageModuleLoadCommand = null;
     this.gatewayUsageExecutable = null;
   }
@@ -711,26 +711,26 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
     __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __MAXMEMORYPERNODE_ISSET_ID, value);
   }
 
-  public boolean isXsedeGatewayUsageReporting() {
-    return this.xsedeGatewayUsageReporting;
+  public boolean isGatewayUsageReporting() {
+    return this.gatewayUsageReporting;
   }
 
-  public void setXsedeGatewayUsageReporting(boolean xsedeGatewayUsageReporting) {
-    this.xsedeGatewayUsageReporting = xsedeGatewayUsageReporting;
-    setXsedeGatewayUsageReportingIsSet(true);
+  public void setGatewayUsageReporting(boolean gatewayUsageReporting) {
+    this.gatewayUsageReporting = gatewayUsageReporting;
+    setGatewayUsageReportingIsSet(true);
   }
 
-  public void unsetXsedeGatewayUsageReporting() {
-    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __XSEDEGATEWAYUSAGEREPORTING_ISSET_ID);
+  public void unsetGatewayUsageReporting() {
+    __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __GATEWAYUSAGEREPORTING_ISSET_ID);
   }
 
-  /** Returns true if field xsedeGatewayUsageReporting is set (has been assigned a value) and false otherwise */
-  public boolean isSetXsedeGatewayUsageReporting() {
-    return EncodingUtils.testBit(__isset_bitfield, __XSEDEGATEWAYUSAGEREPORTING_ISSET_ID);
+  /** Returns true if field gatewayUsageReporting is set (has been assigned a value) and false otherwise */
+  public boolean isSetGatewayUsageReporting() {
+    return EncodingUtils.testBit(__isset_bitfield, __GATEWAYUSAGEREPORTING_ISSET_ID);
   }
 
-  public void setXsedeGatewayUsageReportingIsSet(boolean value) {
-    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __XSEDEGATEWAYUSAGEREPORTING_ISSET_ID, value);
+  public void setGatewayUsageReportingIsSet(boolean value) {
+    __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __GATEWAYUSAGEREPORTING_ISSET_ID, value);
   }
 
   public String getGatewayUsageModuleLoadCommand() {
@@ -869,11 +869,11 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
       }
       break;
 
-    case XSEDE_GATEWAY_USAGE_REPORTING:
+    case GATEWAY_USAGE_REPORTING:
       if (value == null) {
-        unsetXsedeGatewayUsageReporting();
+        unsetGatewayUsageReporting();
       } else {
-        setXsedeGatewayUsageReporting((Boolean)value);
+        setGatewayUsageReporting((Boolean)value);
       }
       break;
 
@@ -931,8 +931,8 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
     case MAX_MEMORY_PER_NODE:
       return getMaxMemoryPerNode();
 
-    case XSEDE_GATEWAY_USAGE_REPORTING:
-      return isXsedeGatewayUsageReporting();
+    case GATEWAY_USAGE_REPORTING:
+      return isGatewayUsageReporting();
 
     case GATEWAY_USAGE_MODULE_LOAD_COMMAND:
       return getGatewayUsageModuleLoadCommand();
@@ -973,8 +973,8 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
       return isSetDataMovementInterfaces();
     case MAX_MEMORY_PER_NODE:
       return isSetMaxMemoryPerNode();
-    case XSEDE_GATEWAY_USAGE_REPORTING:
-      return isSetXsedeGatewayUsageReporting();
+    case GATEWAY_USAGE_REPORTING:
+      return isSetGatewayUsageReporting();
     case GATEWAY_USAGE_MODULE_LOAD_COMMAND:
       return isSetGatewayUsageModuleLoadCommand();
     case GATEWAY_USAGE_EXECUTABLE:
@@ -1095,12 +1095,12 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
         return false;
     }
 
-    boolean this_present_xsedeGatewayUsageReporting = true && this.isSetXsedeGatewayUsageReporting();
-    boolean that_present_xsedeGatewayUsageReporting = true && that.isSetXsedeGatewayUsageReporting();
-    if (this_present_xsedeGatewayUsageReporting || that_present_xsedeGatewayUsageReporting) {
-      if (!(this_present_xsedeGatewayUsageReporting && that_present_xsedeGatewayUsageReporting))
+    boolean this_present_gatewayUsageReporting = true && this.isSetGatewayUsageReporting();
+    boolean that_present_gatewayUsageReporting = true && that.isSetGatewayUsageReporting();
+    if (this_present_gatewayUsageReporting || that_present_gatewayUsageReporting) {
+      if (!(this_present_gatewayUsageReporting && that_present_gatewayUsageReporting))
         return false;
-      if (this.xsedeGatewayUsageReporting != that.xsedeGatewayUsageReporting)
+      if (this.gatewayUsageReporting != that.gatewayUsageReporting)
         return false;
     }
 
@@ -1184,10 +1184,10 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
     if (present_maxMemoryPerNode)
       list.add(maxMemoryPerNode);
 
-    boolean present_xsedeGatewayUsageReporting = true && (isSetXsedeGatewayUsageReporting());
-    list.add(present_xsedeGatewayUsageReporting);
-    if (present_xsedeGatewayUsageReporting)
-      list.add(xsedeGatewayUsageReporting);
+    boolean present_gatewayUsageReporting = true && (isSetGatewayUsageReporting());
+    list.add(present_gatewayUsageReporting);
+    if (present_gatewayUsageReporting)
+      list.add(gatewayUsageReporting);
 
     boolean present_gatewayUsageModuleLoadCommand = true && (isSetGatewayUsageModuleLoadCommand());
     list.add(present_gatewayUsageModuleLoadCommand);
@@ -1320,12 +1320,12 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(isSetXsedeGatewayUsageReporting()).compareTo(other.isSetXsedeGatewayUsageReporting());
+    lastComparison = Boolean.valueOf(isSetGatewayUsageReporting()).compareTo(other.isSetGatewayUsageReporting());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (isSetXsedeGatewayUsageReporting()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.xsedeGatewayUsageReporting, other.xsedeGatewayUsageReporting);
+    if (isSetGatewayUsageReporting()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.gatewayUsageReporting, other.gatewayUsageReporting);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -1467,10 +1467,10 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
       sb.append(this.maxMemoryPerNode);
       first = false;
     }
-    if (isSetXsedeGatewayUsageReporting()) {
+    if (isSetGatewayUsageReporting()) {
       if (!first) sb.append(", ");
-      sb.append("xsedeGatewayUsageReporting:");
-      sb.append(this.xsedeGatewayUsageReporting);
+      sb.append("gatewayUsageReporting:");
+      sb.append(this.gatewayUsageReporting);
       first = false;
     }
     if (isSetGatewayUsageModuleLoadCommand()) {
@@ -1699,10 +1699,10 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
             break;
-          case 12: // XSEDE_GATEWAY_USAGE_REPORTING
+          case 12: // GATEWAY_USAGE_REPORTING
             if (schemeField.type == org.apache.thrift.protocol.TType.BOOL) {
-              struct.xsedeGatewayUsageReporting = iprot.readBool();
-              struct.setXsedeGatewayUsageReportingIsSet(true);
+              struct.gatewayUsageReporting = iprot.readBool();
+              struct.setGatewayUsageReportingIsSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -1848,9 +1848,9 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
         oprot.writeI32(struct.maxMemoryPerNode);
         oprot.writeFieldEnd();
       }
-      if (struct.isSetXsedeGatewayUsageReporting()) {
-        oprot.writeFieldBegin(XSEDE_GATEWAY_USAGE_REPORTING_FIELD_DESC);
-        oprot.writeBool(struct.xsedeGatewayUsageReporting);
+      if (struct.isSetGatewayUsageReporting()) {
+        oprot.writeFieldBegin(GATEWAY_USAGE_REPORTING_FIELD_DESC);
+        oprot.writeBool(struct.gatewayUsageReporting);
         oprot.writeFieldEnd();
       }
       if (struct.gatewayUsageModuleLoadCommand != null) {
@@ -1914,7 +1914,7 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
       if (struct.isSetMaxMemoryPerNode()) {
         optionals.set(8);
       }
-      if (struct.isSetXsedeGatewayUsageReporting()) {
+      if (struct.isSetGatewayUsageReporting()) {
         optionals.set(9);
       }
       if (struct.isSetGatewayUsageModuleLoadCommand()) {
@@ -1988,8 +1988,8 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
       if (struct.isSetMaxMemoryPerNode()) {
         oprot.writeI32(struct.maxMemoryPerNode);
       }
-      if (struct.isSetXsedeGatewayUsageReporting()) {
-        oprot.writeBool(struct.xsedeGatewayUsageReporting);
+      if (struct.isSetGatewayUsageReporting()) {
+        oprot.writeBool(struct.gatewayUsageReporting);
       }
       if (struct.isSetGatewayUsageModuleLoadCommand()) {
         oprot.writeString(struct.gatewayUsageModuleLoadCommand);
@@ -2103,8 +2103,8 @@ public class ComputeResourceDescription implements org.apache.thrift.TBase<Compu
         struct.setMaxMemoryPerNodeIsSet(true);
       }
       if (incoming.get(9)) {
-        struct.xsedeGatewayUsageReporting = iprot.readBool();
-        struct.setXsedeGatewayUsageReportingIsSet(true);
+        struct.gatewayUsageReporting = iprot.readBool();
+        struct.setGatewayUsageReportingIsSet(true);
       }
       if (incoming.get(10)) {
         struct.gatewayUsageModuleLoadCommand = iprot.readString();

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/gatewayprofile/GatewayResourceProfile.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/gatewayprofile/GatewayResourceProfile.java b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/gatewayprofile/GatewayResourceProfile.java
index 79a9d0f..ea29157 100644
--- a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/gatewayprofile/GatewayResourceProfile.java
+++ b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/appcatalog/gatewayprofile/GatewayResourceProfile.java
@@ -72,7 +72,7 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
   private static final org.apache.thrift.protocol.TField CREDENTIAL_STORE_TOKEN_FIELD_DESC = new org.apache.thrift.protocol.TField("credentialStoreToken", org.apache.thrift.protocol.TType.STRING, (short)2);
   private static final org.apache.thrift.protocol.TField COMPUTE_RESOURCE_PREFERENCES_FIELD_DESC = new org.apache.thrift.protocol.TField("computeResourcePreferences", org.apache.thrift.protocol.TType.LIST, (short)3);
   private static final org.apache.thrift.protocol.TField STORAGE_PREFERENCES_FIELD_DESC = new org.apache.thrift.protocol.TField("storagePreferences", org.apache.thrift.protocol.TType.LIST, (short)4);
-  private static final org.apache.thrift.protocol.TField XSEDE_USAGE_REPORTING_GATEWAY_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("xsedeUsageReportingGatewayId", org.apache.thrift.protocol.TType.STRING, (short)5);
+  private static final org.apache.thrift.protocol.TField USAGE_REPORTING_GATEWAY_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("usageReportingGatewayId", org.apache.thrift.protocol.TType.STRING, (short)5);
 
   private static final Map<Class<? extends IScheme>, SchemeFactory> schemes = new HashMap<Class<? extends IScheme>, SchemeFactory>();
   static {
@@ -84,7 +84,7 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
   private String credentialStoreToken; // optional
   private List<ComputeResourcePreference> computeResourcePreferences; // optional
   private List<StoragePreference> storagePreferences; // optional
-  private String xsedeUsageReportingGatewayId; // optional
+  private String usageReportingGatewayId; // optional
 
   /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
   public enum _Fields implements org.apache.thrift.TFieldIdEnum {
@@ -92,7 +92,7 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
     CREDENTIAL_STORE_TOKEN((short)2, "credentialStoreToken"),
     COMPUTE_RESOURCE_PREFERENCES((short)3, "computeResourcePreferences"),
     STORAGE_PREFERENCES((short)4, "storagePreferences"),
-    XSEDE_USAGE_REPORTING_GATEWAY_ID((short)5, "xsedeUsageReportingGatewayId");
+    USAGE_REPORTING_GATEWAY_ID((short)5, "usageReportingGatewayId");
 
     private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();
 
@@ -115,8 +115,8 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
           return COMPUTE_RESOURCE_PREFERENCES;
         case 4: // STORAGE_PREFERENCES
           return STORAGE_PREFERENCES;
-        case 5: // XSEDE_USAGE_REPORTING_GATEWAY_ID
-          return XSEDE_USAGE_REPORTING_GATEWAY_ID;
+        case 5: // USAGE_REPORTING_GATEWAY_ID
+          return USAGE_REPORTING_GATEWAY_ID;
         default:
           return null;
       }
@@ -157,7 +157,7 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
   }
 
   // isset id assignments
-  private static final _Fields optionals[] = {_Fields.CREDENTIAL_STORE_TOKEN,_Fields.COMPUTE_RESOURCE_PREFERENCES,_Fields.STORAGE_PREFERENCES,_Fields.XSEDE_USAGE_REPORTING_GATEWAY_ID};
+  private static final _Fields optionals[] = {_Fields.CREDENTIAL_STORE_TOKEN,_Fields.COMPUTE_RESOURCE_PREFERENCES,_Fields.STORAGE_PREFERENCES,_Fields.USAGE_REPORTING_GATEWAY_ID};
   public static final Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> metaDataMap;
   static {
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
@@ -171,7 +171,7 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
     tmpMap.put(_Fields.STORAGE_PREFERENCES, new org.apache.thrift.meta_data.FieldMetaData("storagePreferences", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.ListMetaData(org.apache.thrift.protocol.TType.LIST, 
             new org.apache.thrift.meta_data.StructMetaData(org.apache.thrift.protocol.TType.STRUCT, StoragePreference.class))));
-    tmpMap.put(_Fields.XSEDE_USAGE_REPORTING_GATEWAY_ID, new org.apache.thrift.meta_data.FieldMetaData("xsedeUsageReportingGatewayId", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
+    tmpMap.put(_Fields.USAGE_REPORTING_GATEWAY_ID, new org.apache.thrift.meta_data.FieldMetaData("usageReportingGatewayId", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
     metaDataMap = Collections.unmodifiableMap(tmpMap);
     org.apache.thrift.meta_data.FieldMetaData.addStructMetaDataMap(GatewayResourceProfile.class, metaDataMap);
@@ -211,8 +211,8 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
       }
       this.storagePreferences = __this__storagePreferences;
     }
-    if (other.isSetXsedeUsageReportingGatewayId()) {
-      this.xsedeUsageReportingGatewayId = other.xsedeUsageReportingGatewayId;
+    if (other.isSetUsageReportingGatewayId()) {
+      this.usageReportingGatewayId = other.usageReportingGatewayId;
     }
   }
 
@@ -226,7 +226,7 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
     this.credentialStoreToken = null;
     this.computeResourcePreferences = null;
     this.storagePreferences = null;
-    this.xsedeUsageReportingGatewayId = null;
+    this.usageReportingGatewayId = null;
   }
 
   public String getGatewayID() {
@@ -351,26 +351,26 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
     }
   }
 
-  public String getXsedeUsageReportingGatewayId() {
-    return this.xsedeUsageReportingGatewayId;
+  public String getUsageReportingGatewayId() {
+    return this.usageReportingGatewayId;
   }
 
-  public void setXsedeUsageReportingGatewayId(String xsedeUsageReportingGatewayId) {
-    this.xsedeUsageReportingGatewayId = xsedeUsageReportingGatewayId;
+  public void setUsageReportingGatewayId(String usageReportingGatewayId) {
+    this.usageReportingGatewayId = usageReportingGatewayId;
   }
 
-  public void unsetXsedeUsageReportingGatewayId() {
-    this.xsedeUsageReportingGatewayId = null;
+  public void unsetUsageReportingGatewayId() {
+    this.usageReportingGatewayId = null;
   }
 
-  /** Returns true if field xsedeUsageReportingGatewayId is set (has been assigned a value) and false otherwise */
-  public boolean isSetXsedeUsageReportingGatewayId() {
-    return this.xsedeUsageReportingGatewayId != null;
+  /** Returns true if field usageReportingGatewayId is set (has been assigned a value) and false otherwise */
+  public boolean isSetUsageReportingGatewayId() {
+    return this.usageReportingGatewayId != null;
   }
 
-  public void setXsedeUsageReportingGatewayIdIsSet(boolean value) {
+  public void setUsageReportingGatewayIdIsSet(boolean value) {
     if (!value) {
-      this.xsedeUsageReportingGatewayId = null;
+      this.usageReportingGatewayId = null;
     }
   }
 
@@ -408,11 +408,11 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
       }
       break;
 
-    case XSEDE_USAGE_REPORTING_GATEWAY_ID:
+    case USAGE_REPORTING_GATEWAY_ID:
       if (value == null) {
-        unsetXsedeUsageReportingGatewayId();
+        unsetUsageReportingGatewayId();
       } else {
-        setXsedeUsageReportingGatewayId((String)value);
+        setUsageReportingGatewayId((String)value);
       }
       break;
 
@@ -433,8 +433,8 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
     case STORAGE_PREFERENCES:
       return getStoragePreferences();
 
-    case XSEDE_USAGE_REPORTING_GATEWAY_ID:
-      return getXsedeUsageReportingGatewayId();
+    case USAGE_REPORTING_GATEWAY_ID:
+      return getUsageReportingGatewayId();
 
     }
     throw new IllegalStateException();
@@ -455,8 +455,8 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
       return isSetComputeResourcePreferences();
     case STORAGE_PREFERENCES:
       return isSetStoragePreferences();
-    case XSEDE_USAGE_REPORTING_GATEWAY_ID:
-      return isSetXsedeUsageReportingGatewayId();
+    case USAGE_REPORTING_GATEWAY_ID:
+      return isSetUsageReportingGatewayId();
     }
     throw new IllegalStateException();
   }
@@ -510,12 +510,12 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
         return false;
     }
 
-    boolean this_present_xsedeUsageReportingGatewayId = true && this.isSetXsedeUsageReportingGatewayId();
-    boolean that_present_xsedeUsageReportingGatewayId = true && that.isSetXsedeUsageReportingGatewayId();
-    if (this_present_xsedeUsageReportingGatewayId || that_present_xsedeUsageReportingGatewayId) {
-      if (!(this_present_xsedeUsageReportingGatewayId && that_present_xsedeUsageReportingGatewayId))
+    boolean this_present_usageReportingGatewayId = true && this.isSetUsageReportingGatewayId();
+    boolean that_present_usageReportingGatewayId = true && that.isSetUsageReportingGatewayId();
+    if (this_present_usageReportingGatewayId || that_present_usageReportingGatewayId) {
+      if (!(this_present_usageReportingGatewayId && that_present_usageReportingGatewayId))
         return false;
-      if (!this.xsedeUsageReportingGatewayId.equals(that.xsedeUsageReportingGatewayId))
+      if (!this.usageReportingGatewayId.equals(that.usageReportingGatewayId))
         return false;
     }
 
@@ -546,10 +546,10 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
     if (present_storagePreferences)
       list.add(storagePreferences);
 
-    boolean present_xsedeUsageReportingGatewayId = true && (isSetXsedeUsageReportingGatewayId());
-    list.add(present_xsedeUsageReportingGatewayId);
-    if (present_xsedeUsageReportingGatewayId)
-      list.add(xsedeUsageReportingGatewayId);
+    boolean present_usageReportingGatewayId = true && (isSetUsageReportingGatewayId());
+    list.add(present_usageReportingGatewayId);
+    if (present_usageReportingGatewayId)
+      list.add(usageReportingGatewayId);
 
     return list.hashCode();
   }
@@ -602,12 +602,12 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(isSetXsedeUsageReportingGatewayId()).compareTo(other.isSetXsedeUsageReportingGatewayId());
+    lastComparison = Boolean.valueOf(isSetUsageReportingGatewayId()).compareTo(other.isSetUsageReportingGatewayId());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (isSetXsedeUsageReportingGatewayId()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.xsedeUsageReportingGatewayId, other.xsedeUsageReportingGatewayId);
+    if (isSetUsageReportingGatewayId()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.usageReportingGatewayId, other.usageReportingGatewayId);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -669,13 +669,13 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
       }
       first = false;
     }
-    if (isSetXsedeUsageReportingGatewayId()) {
+    if (isSetUsageReportingGatewayId()) {
       if (!first) sb.append(", ");
-      sb.append("xsedeUsageReportingGatewayId:");
-      if (this.xsedeUsageReportingGatewayId == null) {
+      sb.append("usageReportingGatewayId:");
+      if (this.usageReportingGatewayId == null) {
         sb.append("null");
       } else {
-        sb.append(this.xsedeUsageReportingGatewayId);
+        sb.append(this.usageReportingGatewayId);
       }
       first = false;
     }
@@ -780,10 +780,10 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
             break;
-          case 5: // XSEDE_USAGE_REPORTING_GATEWAY_ID
+          case 5: // USAGE_REPORTING_GATEWAY_ID
             if (schemeField.type == org.apache.thrift.protocol.TType.STRING) {
-              struct.xsedeUsageReportingGatewayId = iprot.readString();
-              struct.setXsedeUsageReportingGatewayIdIsSet(true);
+              struct.usageReportingGatewayId = iprot.readString();
+              struct.setUsageReportingGatewayIdIsSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -841,10 +841,10 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
           oprot.writeFieldEnd();
         }
       }
-      if (struct.xsedeUsageReportingGatewayId != null) {
-        if (struct.isSetXsedeUsageReportingGatewayId()) {
-          oprot.writeFieldBegin(XSEDE_USAGE_REPORTING_GATEWAY_ID_FIELD_DESC);
-          oprot.writeString(struct.xsedeUsageReportingGatewayId);
+      if (struct.usageReportingGatewayId != null) {
+        if (struct.isSetUsageReportingGatewayId()) {
+          oprot.writeFieldBegin(USAGE_REPORTING_GATEWAY_ID_FIELD_DESC);
+          oprot.writeString(struct.usageReportingGatewayId);
           oprot.writeFieldEnd();
         }
       }
@@ -876,7 +876,7 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
       if (struct.isSetStoragePreferences()) {
         optionals.set(2);
       }
-      if (struct.isSetXsedeUsageReportingGatewayId()) {
+      if (struct.isSetUsageReportingGatewayId()) {
         optionals.set(3);
       }
       oprot.writeBitSet(optionals, 4);
@@ -901,8 +901,8 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
           }
         }
       }
-      if (struct.isSetXsedeUsageReportingGatewayId()) {
-        oprot.writeString(struct.xsedeUsageReportingGatewayId);
+      if (struct.isSetUsageReportingGatewayId()) {
+        oprot.writeString(struct.usageReportingGatewayId);
       }
     }
 
@@ -945,8 +945,8 @@ public class GatewayResourceProfile implements org.apache.thrift.TBase<GatewayRe
         struct.setStoragePreferencesIsSet(true);
       }
       if (incoming.get(3)) {
-        struct.xsedeUsageReportingGatewayId = iprot.readString();
-        struct.setXsedeUsageReportingGatewayIdIsSet(true);
+        struct.usageReportingGatewayId = iprot.readString();
+        struct.setUsageReportingGatewayIdIsSet(true);
       }
     }
   }

http://git-wip-us.apache.org/repos/asf/airavata/blob/03cd77a4/thrift-interface-descriptions/data-models/resource-catalog-models/compute_resource_model.thrift
----------------------------------------------------------------------